@@ -2,9 +2,9 @@ import base64
 import tempfile
 import requests
 
-from utils.Lambdas_Helpers import slack_message
-from   utils.aws.secrets        import Secrets
-from   utils.aws.Lambdas        import Lambdas
+from pbx_gs_python_utils.utils.Lambdas_Helpers import slack_message
+from osbot_aws.apis        import Secrets
+from osbot_aws.apis        import Lambdas
 
 
 # def test_send_message(message):
@@ -34,7 +34,7 @@ def run(event, context):
     dot             = event['dot']
 
     (fd, tmp_file)  = tempfile.mkstemp('png)')
-    dot_to_png      = Lambdas('utils.dot_to_png').invoke
+    dot_to_png      = Lambda('utils.dot_to_png').invoke
     png_data        = dot_to_png({"dot": dot, "width" : 500, "channel" : channel})
 
 
